@@ -13,6 +13,7 @@ from unittest.mock import patch
 
 import packvers
 import pytest
+from commoncode.system import on_mac
 from commoncode.testcase import FileDrivenTesting
 from packvers.requirements import Requirement
 
@@ -26,6 +27,7 @@ from python_inspector.resolution import is_valid_version
 from python_inspector.resolution import parse_reqs_from_setup_py_insecurely
 from python_inspector.utils_pypi import PYPI_PUBLIC_REPO
 from python_inspector.utils_pypi import Environment
+from python_inspector.utils_pypi import PypiSimpleRepository
 
 setup_test_env = FileDrivenTesting()
 setup_test_env.test_data_dir = os.path.join(os.path.dirname(__file__), "data")
@@ -45,12 +47,12 @@ def test_get_resolved_dependencies_with_flask_and_python_310():
         as_tree=False,
     )
     assert plist == [
-        "pkg:pypi/click@8.1.6",
+        "pkg:pypi/click@8.1.7",
         "pkg:pypi/flask@2.1.2",
         "pkg:pypi/itsdangerous@2.1.2",
         "pkg:pypi/jinja2@3.1.2",
         "pkg:pypi/markupsafe@2.1.3",
-        "pkg:pypi/werkzeug@2.3.6",
+        "pkg:pypi/werkzeug@3.0.1",
     ]
 
 
@@ -68,13 +70,13 @@ def test_get_resolved_dependencies_with_flask_and_python_310_windows():
         as_tree=False,
     )
     assert plist == [
-        "pkg:pypi/click@8.1.6",
+        "pkg:pypi/click@8.1.7",
         "pkg:pypi/colorama@0.4.6",
         "pkg:pypi/flask@2.1.2",
         "pkg:pypi/itsdangerous@2.1.2",
         "pkg:pypi/jinja2@3.1.2",
         "pkg:pypi/markupsafe@2.1.3",
-        "pkg:pypi/werkzeug@2.3.6",
+        "pkg:pypi/werkzeug@3.0.1",
     ]
 
 
@@ -119,14 +121,43 @@ def test_get_resolved_dependencies_with_tilde_requirement_using_json_api():
         ),
     )
     assert plist == [
-        "pkg:pypi/click@8.1.6",
+        "pkg:pypi/click@8.1.7",
         "pkg:pypi/flask@2.1.3",
         "pkg:pypi/importlib-metadata@6.8.0",
         "pkg:pypi/itsdangerous@2.1.2",
         "pkg:pypi/jinja2@3.1.2",
         "pkg:pypi/markupsafe@2.1.3",
-        "pkg:pypi/werkzeug@2.3.6",
-        "pkg:pypi/zipp@3.16.2",
+        "pkg:pypi/werkzeug@3.0.1",
+        "pkg:pypi/zipp@3.17.0",
+    ]
+
+
+@pytest.mark.online
+@pytest.mark.skipif(on_mac, reason="torch is only available for linux and windows.")
+def test_get_resolved_dependencies_for_version_containing_local_version_identifier():
+    req = Requirement("torch==2.0.0+cpu")
+    req.is_requirement_resolved = True
+    _, plist = get_resolved_dependencies(
+        requirements=[req],
+        environment=Environment(
+            python_version="310",
+            operating_system="linux",
+        ),
+        repos=[
+            PypiSimpleRepository(index_url="https://download.pytorch.org/whl/cpu", credentials=None)
+        ],
+        as_tree=False,
+    )
+
+    assert plist == [
+        "pkg:pypi/filelock@3.9.0",
+        "pkg:pypi/jinja2@3.1.2",
+        "pkg:pypi/markupsafe@2.1.2",
+        "pkg:pypi/mpmath@1.3.0",
+        "pkg:pypi/networkx@3.0",
+        "pkg:pypi/sympy@1.12",
+        "pkg:pypi/torch@2.0.0%2Bcpu",
+        "pkg:pypi/typing-extensions@4.4.0",
     ]
 
 
@@ -146,12 +177,12 @@ def test_without_supported_wheels():
 
     assert plist == [
         "pkg:pypi/autobahn@22.3.2",
-        "pkg:pypi/cffi@1.15.1",
-        "pkg:pypi/cryptography@41.0.3",
+        "pkg:pypi/cffi@1.16.0",
+        "pkg:pypi/cryptography@41.0.5",
         "pkg:pypi/hyperlink@21.0.0",
         "pkg:pypi/idna@3.4",
         "pkg:pypi/pycparser@2.21",
-        "pkg:pypi/setuptools@68.0.0",
+        "pkg:pypi/setuptools@68.2.2",
         "pkg:pypi/txaio@23.1.1",
     ]
 
